import type { ActionProps } from "../action";
import { Action } from "../action";
import type { Job } from "../job";
import type { RegularStep } from "../step";
/**
 * Output structure for the Configure AWS Credentials action.
 */
export interface ConfigureAwsCredentialsOutputs {
    readonly awsAccountId: string;
    readonly awsAccessKeyId: string;
    readonly awsSecretAccessKey: string;
    readonly awsSessionToken: string;
}
/**
 * Properties for configuring the Configure AWS Credentials action in a GitHub Actions workflow.
 */
export interface ConfigureAwsCredentialsProps extends ActionProps {
    readonly awsRegion: string;
    readonly roleToAssume?: string;
    readonly awsAccessKeyId?: string;
    readonly awsSecretAccessKey?: string;
    readonly awsSessionToken?: string;
    readonly webIdentityTokenFile?: string;
    readonly roleDurationSeconds?: string;
    readonly roleSessionName?: string;
    readonly outputCredentials?: boolean;
}
/**
 * Class representing the Configure AWS Credentials action, allowing configuration of AWS credentials
 * within a GitHub Actions workflow.
 */
export declare class ConfigureAwsCredentials extends Action {
    readonly awsRegion: string;
    readonly roleToAssume?: string;
    readonly awsAccessKeyId?: string;
    readonly awsSecretAccessKey?: string;
    readonly awsSessionToken?: string;
    readonly webIdentityTokenFile?: string;
    readonly roleDurationSeconds?: string;
    readonly roleSessionName?: string;
    readonly outputCredentials?: boolean;
    /**
     * Initializes a new instance of the `ConfigureAwsCredentials` action.
     *
     * @param id - A unique identifier for the action instance.
     * @param props - Properties for configuring the Configure AWS Credentials action.
     */
    constructor(id: string, props: ConfigureAwsCredentialsProps);
    /**
     * Binds the action to a job by adding it as a step in the GitHub Actions workflow.
     *
     * @param job - The job to bind the action to.
     * @returns The configured `RegularStep` for the GitHub Actions job.
     */
    bind(job: Job): RegularStep;
    /**
     * Retrieves the outputs of the ConfigureAwsCredentials action.
     *
     * @returns An object containing the output values of the action.
     */
    get outputs(): ConfigureAwsCredentialsOutputs;
}
